==> vue-layout-builder-0.0.2.tgz: package/tests/unit/components/LayoutBuilderContent.spec.js <==
import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import Content from "../../../src/components/LayoutBuilderContent.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Content.vue", () => {
  describe("with html", () => {
    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection: 1,
        indexSectionBlock: 0,
        slotId: 0,
        html: "<div class='foo'></div>"
      },
      store,
      localVue
    });

    it("renders .Content-html with the given html", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-html .foo").length).toBe(1);
    });

    it("doesn't render the Content-placeholder", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-placeholder").length).toBe(
        0
      );
    });
  });

  describe("with html", () => {
    const indexSection = 1;
    const indexSectionBlock = 0;
    const slotId = 0;
    const stub = jest.fn();
    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection,
        indexSectionBlock,
        slotId,
        html: ""
      },
      store,
      localVue
    });

    wrapper.setMethods({ editContent: stub });

    it("doesn't render .Content-html", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-html").length).toBe(0);
    });

    it("renders the Content-placeholder", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-placeholder").length).toBe(
        1
      );
    });

    describe("triggering 'content-edited' on the EmpyState", () => {
      it("calls editContent() witht he correct params", () => {
        wrapper.find("layoutbuilderemptystate-stub").vm.$emit("content-edited");
        expect(stub).toHaveBeenCalledWith({
          indexSection,
          slotId,
          indexSectionBlock,
          newId: 9
        });
      });
    });
  });
});

==> vue-layout-builder-0.0.3.tgz: package/tests/unit/components/LayoutBuilderContent.spec.js <==
import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import Content from "../../../src/components/LayoutBuilderContent.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Content.vue", () => {
  describe("with html", () => {
    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection: 1,
        indexSectionBlock: 0,
        slotId: 0,
        element: {
          html: "<div class='foo'></div>"
        }
      },
      store,
      localVue
    });

    it("renders .Content-html with the given html", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-html .foo").length).toBe(1);
    });

    it("doesn't render the Content-placeholder", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-placeholder").length).toBe(
        0
      );
    });
  });

  describe("with html", () => {
    const indexSection = 1;
    const indexSectionBlock = 0;
    const slotId = 0;
    const stub = jest.fn();
    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection,
        indexSectionBlock,
        slotId
      },
      store,
      localVue
    });

    wrapper.setMethods({ showContentTypesOverlay: stub });

    it("doesn't render .Content-html", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-html").length).toBe(0);
    });

    it("renders the Content-placeholder", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-placeholder").length).toBe(
        1
      );
    });

    describe("triggering 'add-content-clicked' on the EmpyState", () => {
      it("calls showContentTypesOverlay() witht he correct params", () => {
        wrapper
          .find("layoutbuilderemptystate-stub")
          .vm.$emit("add-content-clicked");
        expect(stub).toHaveBeenCalledWith({
          indexSection,
          slotId,
          indexSectionBlock
        });
      });
    });
  });
});
